@@ -1,13 +1,15 @@
+import pydantic
 import platform
 import sys
 import pymongo
 import motor
 
 
-VERSION = "0.9.1"
+VERSION = "1.1.0"
 
 info = {
     "PyODMongo version": VERSION,
+    "Pydantic version": pydantic.version.VERSION,
     "Pymongo version": pymongo.__version__,
     "Motor version": motor._version.version,
     "Python version": sys.version,
